bayespy.inference.vmp.transformations.RotateGaussianARD
=======================================================

.. currentmodule:: bayespy.inference.vmp.transformations

.. autoclass:: RotateGaussianARD

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
      :toctree: generated/
   
      ~RotateGaussianARD.__init__
      ~RotateGaussianARD.bound
      ~RotateGaussianARD.get_bound_terms
      ~RotateGaussianARD.nodes
      ~RotateGaussianARD.rotate
      ~RotateGaussianARD.setup
   
   

   
   
   